django-simple-faq
=================

Simple FAQ app for django

* pip install django-simple-faq
* Add simple_faq and tinymce to INSTALLED_APPS
* Add simple_faq's and tinymce's urls to your project's urls.py